@@ -10,7 +10,12 @@ import publication
 
 import aws_cdk.core._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-imagebuilder", "1.49.1", __name__[0:-6], "aws-imagebuilder@1.49.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-imagebuilder",
+    "1.50.0",
+    __name__[0:-6],
+    "aws-imagebuilder@1.50.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
